==> v5.5.1.zip: fabulously-optimized/README.md <==
# Fabulously Optimized

A Fabric-based Minecraft modpack focusing on performance and graphics enhancements.

[**📜 Mod list**](INCLUDED-MODS.md) | [**🎛️ Changed options**](https://wiki.download.fo/readme/changed-options) | [**❤️ Support and contribute**](https://download.fo/thanks)

<a href="https://wiki.download.fo/"><img alt="Wiki" height="40" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/compact/documentation/gitbook_vector.svg"></a> 
<a href="https://download.fo/translate"><img alt="Translate" height="40" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/compact/translate/generic-plural_vector.svg"></a>

<a href="https://download.fo/discord"><img alt="Discord" height="40" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/compact/social/discord-plural_vector.svg"></a> 
<a href="https://download.fo/mastodon"><img alt="Mastodon" height="40" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/compact/social/mastodon-plural_vector.svg"></a>

## Downloads

[![Download from CurseForge](https://cf.way2muchnoise.eu/full_fabulously-optimized_downloads%20on%20CurseForge.svg?badge_style=for_the_badge)](https://download.fo/curseforge) [![Modrinth](https://img.shields.io/modrinth/dt/fabulously-optimized?logo=modrinth&color=darkgreen&label=Download%20from%20Modrinth&style=for-the-badge)](https://download.fo/modrinth) [![How to install](https://i.ibb.co/FbKTDYs/github.png)](https://download.fo/install)

We encourage using CurseForge Launcher, Prism Launcher, MultiMC, or vanilla launcher.

<details>
  <summary>Alternative downloads</summary>

_These downloads do not yet support the modpack or the mods :(_
* [MultiMC (auto-update)](https://wiki.download.fo/readme/multimc-auto-update): [1.16.5](https://github.com/Fabulously-Optimized/fabulously-optimized/releases/download/v3.2.3/Fabulously.Optimized.MC.1.16.5.auto-update.zip) | [1.17.1](https://github.com/Fabulously-Optimized/fabulously-optimized/releases/download/v3.2.3/Fabulously.Optimized.MC.1.17.1.auto-update.zip) | [1.18.2](https://github.com/Fabulously-Optimized/fabulously-optimized/releases/download/v3.12.2/Fabulously.Optimized.MC.1.18.2.auto-update.zip) | [1.19.4](https://github.com/Fabulously-Optimized/fabulously-optimized/releases/download/v4.10.0/Fabulously.Optimized.MC.1.19.4.auto-update.zip) | [1.20.2](https://github.com/Fabulously-Optimized/fabulously-optimized/releases/download/v5.5.0-beta.2/Fabulously.Optimized.MC.1.20.2.auto-update.zip)
* ~~Vanilla installer~~ [(planned)](https://github.com/Madis0/fabulously-optimized/issues/110)
* [GitHub releases](https://github.com/Fabulously-Optimized/fabulously-optimized/releases)
* Chat Reporting Helper resource pack: [CurseForge](https://www.curseforge.com/minecraft/texture-packs/chat-reporting-helper) | 
[Modrinth](https://modrinth.com/resourcepack/chat-reporting-helper) |
[Planet Minecraft](https://www.planetminecraft.com/texture-pack/chat-reporting-helper) (bundled in FO)
* Fast Better Grass resource pack: [CurseForge](https://www.curseforge.com/minecraft/texture-packs/fast-better-grass) | [Modrinth](https://modrinth.com/resourcepack/fast-better-grass) | [Planet Minecraft](https://www.planetminecraft.com/texture-pack/fast-better-grass) (bundled in FO)
</details>

Not sure which edition is right for you? Check this handy table!
| Feature/Edition | [CurseForge Launcher](https://www.curseforge.com/download/app) | [Prism Launcher](https://prismlauncher.org/) | [MultiMC](https://multimc.org) | [MultiMC](https://multimc.org) (auto-update) | [Vanilla launcher](https://www.minecraft.net/en-us/download) (manual install) |
|---|---|---|---|---|---|
| Installation tutorial | [Tutorial](https://wiki.download.fo/readme/install-instructions#curseforge-launcher) | [Tutorial](https://wiki.download.fo/readme/install-instructions#prism-launcher) | [Tutorial](https://wiki.download.fo/readme/install-instructions#multimc) | [Tutorial](https://wiki.download.fo/readme/install-instructions#multimc-auto-update) | [Tutorial](https://wiki.download.fo/readme/install-instructions#minecraft-launcher-vanilla) |
| Easy install | ✅ | ✅ | ✅ | ✅ | ❌ |
| Easy pack upgrade | ✅ | ✅ | ❌ | ✅ | ❌ |
| Easy pack upgrade for newer MC | ✅ | ✅ | ❌ | ❌ | ❌ |
| Add mods with few clicks | ✅ | ✅ | ❌ | ❌ | ❌ |
| Supports the modpack and mods | ✅ | ●¹ | ●¹ | ❌ | ✅ |
| Can be used offline | ✅ | ✅ | ✅ | ✅ | ✅ |
| Linux support | ❌ | ✅ | ✅ | ✅ | ✅ |
| Unique feature | 1-click install | Steam Deck support | Nostalgic UI | Always up to date | Familiarity |

¹ Supports the modpack by increasing its download count, but not with monetary benefits.

## Accessibility

Fabulously Optimized is designed to be accessible for everyone, and as such contains the following accessibility features on its latest version.

* The first-run accessibility screen is not used, to make setup smoother and faster. Instead, users can continue to take advantage of the menu keyboard support.
  * Languages screen can be accessed by pressing <kbd>→</kbd> <kbd>Enter</kbd>.
  * Accessibility screen can be accessed by pressing <kbd>←</kbd> <kbd>←</kbd> <kbd>Enter</kbd>.
  * Narrator can be directly enabled by pressing <kbd>Ctrl</kbd> + <kbd>B</kbd>.
* Users can search for and select multiple languages
  * User's native language is automatically applied (where supported)
  * Selecting multiple languages is useful for users who know several, and for languages with variants (like Spanish), to ensure mods are translated as much as possible
  * Items have the original names on their tooltips for command usage purposes
* Game controllers are supported
* [Several launchers are supported](#downloads)
* [The purpose and settings for each included mod are displayed in the mod menu](https://wiki.download.fo/readme/changed-options#resource-packs)
* Splash screen is black, similar to Bedrock Edition
* Other [changed options](https://wiki.download.fo/readme/changed-options) to match users' expectations
* For more accessibility features, try the mod [Minecraft Access](https://modrinth.com/mod/minecraft-access/)

## Disclaimers

By using this modpack, you agree to the following:

* The modpack has been set up to be compatible with the rules of most public third-party servers, but it is your responsibility to verify whether you are allowed to use it or not. By installing this modpack you agree that the modpack author, the mod developers and Mojang provide no warranties for using this modpack, every action you do with it is your own.
  * The modpack supports controllers with analog input, whose usage may trigger anticheats on some servers due to unexpectedly smooth movement. If the playing server rules disallow analog input, the user is expected to add the server to mod whitelist, or disable analog input entirely.
* This modpack disables the [third-party server disclaimer](https://minecraft.wiki/w/File:Multiplayer_disclaimer.png), so if you are using the multiplayer function, you also agree to the following: 
    > Caution: Online play is offered by third-party servers that are not owned, operated, or supervised by Mojang Studios or Microsoft. During online play, you may be exposed to unmoderated chat messages or other types of user-generated content that may not be suitable for everyone. 
    *  [The "social interactions" screen](https://minecraft.wiki/w/wiki/Social_Interactions_screen#Usage) can be used by pressing the key `P` in-game or the `Player Reporting` button in the pause menu.
    * On servers where chat signing is optional, the modpack opts out of it for the playing user to adhere to server's intent. An indicator icon is added to inform players of the signing status in the server (whether the server supports Mojang's chat safety features). [Read more](https://wiki.download.fo/readme/chat-reporting-faq#what-does-this-modpack-do-for-me).
* [Per the privacy and familiarity goals](https://wiki.download.fo/readme/principles), the modpack disables Mojang's analytics collection, individual mod update checkers and cosmetic donor features, plus any other network services that may invade privacy or cause confusion. All of these can be re-enabled by users in the respective configs.
* Fabulously Optimized does not host any capes or other cosmetics, nor does it encourage users to buy them from any provider. Instead, the modpack encourages users to [prefer free cosmetics](https://wiki.download.fo/readme/free-cape), while also giving them options to use any paid cosmetics they've previously obtained from certain providers.  
* Yes, you can fork/remix this pack [according to the license](LICENSE.md). You cannot, however, use the "Fabulously Optimized" name or logo to _represent_ your fork (but you can mention that you forked it).
* NOT AN OFFICIAL MINECRAFT PRODUCT. NOT APPROVED BY OR ASSOCIATED WITH MOJANG OR MICROSOFT.

<br>
<details>
  
  <summary>Free badges for forks <a href="https://intergrav.github.io/devins-badges-docs">by Devin</a></summary>
  
  <a href="https://download.fo"><img alt="Built on Fabulously Optimized" height="56" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/cozy/built-with/fabulously-optimized_vector.svg"></a>
  
  Markdown and HTML for Modrinth/GitHub below; for CurseForge just select and copy the image to get it with the link.
  ```html
  <!-- Markdown -->
  [![Built on Fabulously Optimized](https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/cozy/built-with/fabulously-optimized_64h.png)](https://download.fo)

  <!-- HTML (resizeable) -->
  <a href="https://download.fo"><img alt="Built on Fabulously Optimized" height="56" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/cozy/built-with/fabulously-optimized_vector.svg"></a>
  ```
  <a href="https://download.fo"><img alt="Built on Fabulously Optimized" height="40" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/compact/built-with/fabulously-optimized_vector.svg"></a>
  
  Markdown and HTML for Modrinth/GitHub below; for CurseForge just select and copy the image to get it with the link.
  ```html
  <!-- Markdown -->
  [![Built on Fabulously Optimized](https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/compact/built-with/fabulously-optimized_46h.png)](https://download.fo)
  <!-- HTML (resizeable) -->
  <a href="https://download.fo"><img alt="Built on Fabulously Optimized" height="40" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/compact/built-with/fabulously-optimized_vector.svg"></a>
  ```
  
</details>

==> v5.6.0.zip: fabulously-optimized/README.md <==
# Fabulously Optimized

A Fabric-based Minecraft modpack focusing on performance and graphics enhancements.

[**📜 Mod list**](INCLUDED-MODS.md) | [**🎛️ Changed options**](https://wiki.download.fo/readme/changed-options) | [**❤️ Support and contribute**](https://download.fo/thanks)

<a href="https://wiki.download.fo/"><img alt="Wiki" height="40" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/compact/documentation/gitbook_vector.svg"></a> 
<a href="https://download.fo/translate"><img alt="Translate" height="40" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/compact/translate/generic-plural_vector.svg"></a>

<a href="https://download.fo/discord"><img alt="Discord" height="40" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/compact/social/discord-plural_vector.svg"></a> 
<a href="https://download.fo/mastodon"><img alt="Mastodon" height="40" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/compact/social/mastodon-plural_vector.svg"></a>

## Downloads

[![Download from CurseForge](https://cf.way2muchnoise.eu/full_fabulously-optimized_downloads%20on%20CurseForge.svg?badge_style=for_the_badge)](https://download.fo/curseforge) [![Modrinth](https://img.shields.io/modrinth/dt/fabulously-optimized?logo=modrinth&color=darkgreen&label=Download%20from%20Modrinth&style=for-the-badge)](https://download.fo/modrinth) [![How to install](https://i.ibb.co/FbKTDYs/github.png)](https://download.fo/install)

We encourage using CurseForge App, Modrinth App, Prism Launcher, MultiMC, or vanilla launcher.

<details>
  <summary>Alternative downloads</summary>

_These downloads do not yet support the modpack or the mods :(_
* [MultiMC (auto-update)](https://wiki.download.fo/readme/multimc-auto-update): [1.16.5](https://github.com/Fabulously-Optimized/fabulously-optimized/releases/download/v3.2.3/Fabulously.Optimized.MC.1.16.5.auto-update.zip) | [1.17.1](https://github.com/Fabulously-Optimized/fabulously-optimized/releases/download/v3.2.3/Fabulously.Optimized.MC.1.17.1.auto-update.zip) | [1.18.2](https://github.com/Fabulously-Optimized/fabulously-optimized/releases/download/v3.12.2/Fabulously.Optimized.MC.1.18.2.auto-update.zip) | [1.19.4](https://github.com/Fabulously-Optimized/fabulously-optimized/releases/download/v4.10.0/Fabulously.Optimized.MC.1.19.4.auto-update.zip) | [1.20.2](https://github.com/Fabulously-Optimized/fabulously-optimized/releases/download/v5.5.0-beta.2/Fabulously.Optimized.MC.1.20.2.auto-update.zip)
* ~~Vanilla installer~~ [(planned)](https://github.com/Madis0/fabulously-optimized/issues/110)
* [GitHub releases](https://github.com/Fabulously-Optimized/fabulously-optimized/releases)
* Chat Reporting Helper resource pack: [CurseForge](https://www.curseforge.com/minecraft/texture-packs/chat-reporting-helper) | 
[Modrinth](https://modrinth.com/resourcepack/chat-reporting-helper) |
[Planet Minecraft](https://www.planetminecraft.com/texture-pack/chat-reporting-helper) (bundled in FO)
* Fast Better Grass resource pack: [CurseForge](https://www.curseforge.com/minecraft/texture-packs/fast-better-grass) | [Modrinth](https://modrinth.com/resourcepack/fast-better-grass) | [Planet Minecraft](https://www.planetminecraft.com/texture-pack/fast-better-grass) (bundled in FO)
</details>

Not sure which edition is right for you? Check this handy table!

| Feature/Edition | [CurseForge App](https://www.curseforge.com/download/app) | [Modrinth App](https://modrinth.com/app) | [Prism Launcher](https://prismlauncher.org/) | [MultiMC](https://multimc.org) | [MultiMC](https://multimc.org) (auto-update) | [Minecraft Launcher](https://www.minecraft.net/en-us/download) (vanilla - manual install) |
|---|---|---|---|---|---|---|
| Installation tutorial | [Tutorial](https://wiki.download.fo/readme/install-instructions#curseforge-app) |  [Tutorial](https://wiki.download.fo/readme/install-instructions#modrinth-app) | [Tutorial](https://wiki.download.fo/readme/install-instructions#prism-launcher) | [Tutorial](https://wiki.download.fo/readme/install-instructions#multimc) | [Tutorial](https://wiki.download.fo/readme/install-instructions#multimc-auto-update) | [Tutorial](https://wiki.download.fo/readme/install-instructions#minecraft-launcher-vanilla) |
| Easy install | ✅ | ✅ | ✅ | ✅ | ✅ | ❌ |
| Easy pack upgrade | ✅ | ✅ | ✅ | ❌ | ✅ | ❌ |
| Easy pack upgrade for newer MC | ✅ | ✅ | ✅ | ❌ | ❌ | ❌ |
| Add mods with few clicks | ✅ | ✅ | ✅ | ❌ | ❌ | ❌ |
| Supports the modpack and mods | ✅ | ✅ | ●¹ | ●¹ | ●¹ | ✅ |
| Can be used offline | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ |
| Linux support | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ |
| Unique feature | 1-click install from site | Import from other launchers | Steam Deck support | Nostalgic UI | Always up to date | Familiarity |

¹ Supports the modpack by increasing its download count, but not with monetary benefits.

## Accessibility

Fabulously Optimized is designed to be accessible for everyone, and as such contains the following accessibility features on its latest version.

* The first-run accessibility screen is not used, to make setup smoother and faster. Instead, users can continue to take advantage of the menu keyboard support.
  * Languages screen can be accessed by pressing <kbd>→</kbd> <kbd>Enter</kbd>.
  * Accessibility screen can be accessed by pressing <kbd>←</kbd> <kbd>←</kbd> <kbd>Enter</kbd>.
  * Narrator can be directly enabled by pressing <kbd>Ctrl</kbd> + <kbd>B</kbd>.
* Users can search for and select multiple languages
  * User's native language is automatically applied (where supported)
  * Selecting multiple languages is useful for users who know several, and for languages with variants (like Spanish), to ensure mods are translated as much as possible
  * Items have the original names on their tooltips for command usage purposes
* Game controllers are supported
* [Several launchers are supported](#downloads)
* [The purpose and settings for each included mod are displayed in the mod menu](https://wiki.download.fo/readme/changed-options#resource-packs)
* Splash screen is black, similar to Bedrock Edition
* Other [changed options](https://wiki.download.fo/readme/changed-options) to match users' expectations
* For more accessibility features, try the mod [Minecraft Access](https://modrinth.com/mod/minecraft-access/)

## Disclaimers

By using this modpack, you agree to the following:

* The modpack has been set up to be compatible with the rules of most public third-party servers, but it is your responsibility to verify whether you are allowed to use it or not. By installing this modpack you agree that the modpack author, the mod developers and Mojang provide no warranties for using this modpack, every action you do with it is your own.
  * The modpack supports controllers with analog input, whose usage may trigger anticheats on some servers due to unexpectedly smooth movement. If the playing server rules disallow analog input, the user is expected to add the server to mod whitelist, or disable analog input entirely.
* This modpack disables the [third-party server disclaimer](https://minecraft.wiki/w/File:Multiplayer_disclaimer.png), so if you are using the multiplayer function, you also agree to the following: 
    > Caution: Online play is offered by third-party servers that are not owned, operated, or supervised by Mojang Studios or Microsoft. During online play, you may be exposed to unmoderated chat messages or other types of user-generated content that may not be suitable for everyone. 
    *  [The "social interactions" screen](https://minecraft.wiki/w/wiki/Social_Interactions_screen#Usage) can be used by pressing the key `P` in-game or the `Player Reporting` button in the pause menu.
    * On servers where chat signing is optional, the modpack opts out of it for the playing user to adhere to server's intent. An indicator icon is added to inform players of the signing status in the server (whether the server supports Mojang's chat safety features). [Read more](https://wiki.download.fo/readme/chat-reporting-faq#what-does-this-modpack-do-for-me).
* [Per the privacy and familiarity goals](https://wiki.download.fo/readme/principles), the modpack disables Mojang's analytics collection, individual mod update checkers and cosmetic donor features, plus any other network services that may invade privacy or cause confusion. All of these can be re-enabled by users in the respective configs.
* Fabulously Optimized does not host any capes or other cosmetics, nor does it encourage users to buy them from any provider. Instead, the modpack encourages users to [prefer free cosmetics](https://wiki.download.fo/readme/free-cape), while also giving them options to use any paid cosmetics they've previously obtained from certain providers.  
* Yes, you can fork/remix this pack [according to the license](LICENSE.md). You cannot, however, use the "Fabulously Optimized" name or logo to _represent_ your fork (but you can mention that you forked it).
* NOT AN OFFICIAL MINECRAFT PRODUCT. NOT APPROVED BY OR ASSOCIATED WITH MOJANG OR MICROSOFT.

<br>
<details>
  
  <summary>Free badges for forks <a href="https://intergrav.github.io/devins-badges-docs">by Devin</a></summary>
  
  <a href="https://download.fo"><img alt="Built on Fabulously Optimized" height="56" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/cozy/built-with/fabulously-optimized_vector.svg"></a>
  
  Markdown and HTML for Modrinth/GitHub below; for CurseForge just select and copy the image to get it with the link.
  ```html
  <!-- Markdown -->
  [![Built on Fabulously Optimized](https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/cozy/built-with/fabulously-optimized_64h.png)](https://download.fo)

  <!-- HTML (resizeable) -->
  <a href="https://download.fo"><img alt="Built on Fabulously Optimized" height="56" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/cozy/built-with/fabulously-optimized_vector.svg"></a>
  ```
  <a href="https://download.fo"><img alt="Built on Fabulously Optimized" height="40" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/compact/built-with/fabulously-optimized_vector.svg"></a>
  
  Markdown and HTML for Modrinth/GitHub below; for CurseForge just select and copy the image to get it with the link.
  ```html
  <!-- Markdown -->
  [![Built on Fabulously Optimized](https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/compact/built-with/fabulously-optimized_46h.png)](https://download.fo)
  <!-- HTML (resizeable) -->
  <a href="https://download.fo"><img alt="Built on Fabulously Optimized" height="40" src="https://cdn.jsdelivr.net/npm/@intergrav/devins-badges@3/assets/compact/built-with/fabulously-optimized_vector.svg"></a>
  ```
  
</details>
